import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:furman_now/src/screens/events/index.dart';
import 'package:furman_now/src/screens/home/home_header.dart';
import 'package:furman_now/src/screens/home/index.dart';
import 'package:furman_now/src/screens/info/contacts.dart';
import 'package:furman_now/src/screens/info/health_safety.dart';
import 'package:furman_now/src/screens/info/hours.dart';
import 'package:furman_now/src/screens/info/index.dart';
import 'package:furman_now/src/screens/settings/settings.dart';
import 'package:furman_now/src/screens/map/index.dart';
import 'package:furman_now/src/screens/map/map_category.dart';
import 'package:furman_now/src/screens/map/map_home.dart';
import 'package:furman_now/src/screens/student_id/index.dart';
import 'package:furman_now/src/utils/hero_empty_router_page.dart';
import 'package:furman_now/src/utils/translucent_route.dart';

import '../layouts/main/index.dart';

Route<T> mapRouteBuilder<T>(BuildContext context, Widget child, CustomPage<T> page) {
  return TranslucentRoute(
    settings: page,
    transitionDuration: const Duration(milliseconds: 200),
    transitionBuilder: (context, animation, secondaryAnimation, child) =>
      FadeTransition(
        opacity: animation,
        child: FadeTransition(
          opacity: secondaryAnimation.drive(Tween<double>(begin: 1, end: 0)),
          child: child,
        ),
      ),
    pageBuilder: (context, _, __) => child,
  );
}

@MaterialAutoRouter(
  replaceInRouteName: 'Screen,Route',
  routes: <AutoRoute>[
    AutoRoute(path: "/", page: MainLayout, children: [
      AutoRoute(path: "home", name: "HomePageRouter", page: HomeScreen, children: [
        CustomRoute(
          path: "",
          page: HomePageHeader,
          name: "HomeRoute",
          transitionsBuilder: TransitionsBuilders.fadeIn,
        ),
        CustomRoute(
          path: "student-id",
          page: StudentIdScreen,
          transitionsBuilder: TransitionsBuilders.fadeIn,
        ),
      ]),
      AutoRoute(path: "map", page: MapScreen, children: [
        CustomRoute(
          path: "",
          page: MapHomeScreen,
          customRouteBuilder: mapRouteBuilder,
        ),
        CustomRoute(
          path: "category/:id",
          page: MapCategoryScreen,
          customRouteBuilder: mapRouteBuilder,
        ),
      ]),
      AutoRoute(path: "events", page: EventsScreen),
      AutoRoute(path: "info", name: "InfoPageRouter", page: HeroEmptyRouterPage, children: [
        AutoRoute(path: "", page: InfoScreen),
        AutoRoute(path: "health-and-safety", page: HealthSafetyScreen),
        AutoRoute(path: "contacts", page: ContactsScreen),
        AutoRoute(path: "hours", page: HoursScreen),
        AutoRoute(path: "settings", page: SettingsScreen),
      ]),
    ]),
  ],
)
class $AppRouter {}