import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:furman_now/src/layouts/app_page.dart';
import 'package:furman_now/src/utils/date_range.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:furman_now/src/widgets/header.dart';
import 'package:furman_now/src/widgets/events/events_list.dart';
import 'package:furman_now/src/widgets/scroll_view_height.dart';
import 'package:intl/intl.dart';

class EventsScreen extends StatelessWidget {
  const EventsScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppPageLayout(
      title: "Events",
      icon: FlutterRemix.calendar_line,
      content: Padding(
        padding: const EdgeInsets.symmetric(vertical: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const HeaderWidget(title: "Today"),
            Padding(
                padding: const EdgeInsets.symmetric(horizontal: 20),
                child: EventsList()
            ),
            const HeaderWidget(title: "Tomorrow"),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 20),
              child: EventsList(dateRange: constructDateRange(
                DateTime.now().add(const Duration(days: 1)),
                DateTime.now().add(const Duration(days: 1)),
              )),
            ),
            ...[for(var i=2; i<7; i+=1) i].map((i) {
              var date = DateTime.now().add(Duration(days: i));
              var dayName = DateFormat('EEEE').format(date);
              return Wrap(
                children: [
                  HeaderWidget(title: dayName),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 20),
                    child: EventsList(dateRange: constructDateRange(
                      date,
                      date,
                    )),
                  ),
                ],
              );
            }),
            Center(child:
            Wrap(
              direction: Axis.vertical,
              crossAxisAlignment: WrapCrossAlignment.center,
              children: const [
                Text("Need more events?"),
                Text("Syncdin"),
                Text("Athletics"),
                Text("CLPs"),
              ],
            ),
            ),
          ],
        ),
      ),
    );
  }
}
