import 'package:flutter/material.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/widgets/events/events_list.dart';
import 'package:furman_now/src/widgets/header.dart';
import 'package:furman_now/src/widgets/home/restaurants/restaurants_list.dart';
import 'package:furman_now/src/widgets/home/transportation/transportation_card.dart';
import 'package:furman_now/src/widgets/scroll_view_height.dart';

class HomeContent extends StatefulWidget {
  final bool collapse;
  final ScrollController controller;

  const HomeContent({
    required this.collapse,
    required this.controller,
    Key? key,
  }) : super(key: key);

  @override
  State<HomeContent> createState() => _HomeContentState();
}

class _HomeContentState extends State<HomeContent> {
  bool _collapse = false;

  @override
  Widget build(BuildContext context) {
    if (widget.collapse != _collapse) {
      widget.controller.animateTo(
        0,
        duration: const Duration(milliseconds: 400),
        curve: Curves.easeInOut,
      );
      _collapse = widget.collapse;
    }

    return LayoutBuilder(
      builder: (context, constraints) => ScrollViewWithHeight(
        controller: widget.controller,
        child: Align(
          alignment: Alignment.bottomCenter,
          child: TweenAnimationBuilder<double>(
            tween: widget.collapse
              ? Tween<double>(begin: 200, end: constraints.maxHeight - 75)
              : Tween<double>(begin: constraints.maxHeight - 75, end: 200),
            curve: Curves.easeInOut,
            duration: const Duration(milliseconds: 200),
            builder: (context, margin, _) => Stack(
              children: [
                Container(
                  decoration: const BoxDecoration(
                    color: Colors.white,
                    borderRadius:
                      BorderRadius.vertical(
                        top: Radius.circular(30),
                        bottom: Radius.circular(30),
                      ),
                  ),
                  padding: const EdgeInsets.only(bottom: 15),
                  margin: EdgeInsets.only(top: margin),
                  width: double.infinity,
                  constraints: BoxConstraints(
                    minHeight: constraints.maxHeight - margin,
                  ),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      AnimatedContainer(
                        duration: const Duration(milliseconds: 300),
                        height: widget.collapse ? 55 : 0,
                        child: Align(
                          alignment: Alignment.topCenter,
                          child: Container(
                              margin: const EdgeInsets.symmetric(vertical: 15),
                              width: 60,
                              height: 5,
                              decoration: BoxDecoration(
                                color: Colors.grey[300],
                                borderRadius: BorderRadius.circular(20),
                              )
                          ),
                        ),
                      ),
                      const SizedBox(height: 20),
                      const HeaderWidget(
                        title: "Today's Events",
                        link: HeaderLink(
                            text: "View more",
                            href: EventsRoute()
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 20),
                        child: EventsList(),
                      ),
                      const HeaderWidget(title: "Food & Dining"),
                      const RestaurantsList(),
                      const HeaderWidget(title: "Transportation"),
                      const Padding(
                        padding: EdgeInsets.symmetric(horizontal: 20),
                        child: TransportationCard(),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}