import 'package:flutter/material.dart';
import 'package:furman_now/src/screens/home/state.dart';
import 'package:furman_now/src/services/weather/weather_service.dart';
import 'package:furman_now/src/utils/greeting.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:provider/provider.dart';

class HomePageHeader extends StatelessWidget {
  const HomePageHeader({ Key? key }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: 300,
      decoration: const BoxDecoration(
        gradient: LinearGradient(
          begin: Alignment.topCenter,
          end: Alignment.bottomCenter,
          colors: <Color>[
            Color(0xffb7acc9),
            Color(0xffb7acc9),
          ],
          tileMode: TileMode.mirror,
        ),
      ),
      child: Align(
        alignment: Alignment.topLeft,
        child: Container(
          padding: const EdgeInsets.all(40),
          width: double.infinity,
          height: 200,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Hero(
                tag: "title",
                child: Material(
                  type: MaterialType.transparency,
                  child: Text(
                    "${greeting()},\nMichael",
                    style: furmanTextStyle(const TextStyle(
                      color: Color(0xff26183d),
                      fontSize: 36,
                      fontWeight: FontWeight.w800,
                      height: 1.2,
                    )),
                  ),
                ),
              ),
              const SizedBox(height: 8),
              Consumer<HomePageState>(
                builder: (context, state, _) => AnimatedCrossFade(
                  crossFadeState:
                    state.showScrollMessage
                      ? CrossFadeState.showSecond
                      : CrossFadeState.showFirst,
                  duration: const Duration(milliseconds: 100),
                  firstChild: FutureBuilder<String>(
                    future: WeatherService.getWeatherMessage(),
                    builder: (context, snapshot) {
                      if(snapshot.hasData) {
                        return Text(
                          snapshot.data!,
                          // "It's 76º and partly cloudy",
                          style: furmanTextStyle(const TextStyle
                          (
                            color: Color(0xff26183d),
                            fontSize: 16,
                            fontWeight: FontWeight.w500,
                          )),
                        );
                      }
                      return const SizedBox(height: 0);
                    }
                  ),
                  secondChild: Text("Pull down to view your Meal ID",
                    style: furmanTextStyle(const TextStyle(
                        color: Color(0xff26183d),
                        fontSize: 16,
                        fontWeight: FontWeight.w500
                    )),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
