import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:furman_now/src/layouts/app_page.dart';
import 'package:furman_now/src/services/info/contacts_service.dart';
import 'package:furman_now/src/widgets/info/info_card.dart';

class ContactsScreen extends StatelessWidget {
  const ContactsScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppPageLayout(
        title: "Contacts",
        icon: FlutterRemix.arrow_left_line,
        backgroundColor: Colors.deepPurple.shade50,
        iconTapAction: () => context.router.pop(),
        content: Padding(
          padding: const EdgeInsets.all(20),
          child: FutureBuilder<Iterable<ContactInfo>>(
            future: ContactsService.fetchContactInfo(),
            builder: (context, snapshot) {
              if (snapshot.hasData) {
                var items = snapshot.data!;
                return Column(
                    children: items.map((item) {
                      return Padding(
                        padding: const EdgeInsets.only(bottom: 15),
                        child: InfoCard(
                          title: item.name,
                          icon: item.buildingId != 0
                              ? FlutterRemix.building_line
                              : FlutterRemix.contacts_line,
                          items: [
                            InfoCardItem(
                              name: item.phone,
                              icon: FlutterRemix.phone_line
                            ),
                          ],
                          onClick: () => item.launch(),
                        ),
                      );
                    }).toList());
              }
              else if (snapshot.hasError) {
                return Text(
                  '${snapshot.error}',
                  style: const TextStyle(color: Colors.red)
                );
              }
              // By default, show a loading spinner.
              return const Center(
                child: Padding(
                    padding: EdgeInsets.symmetric(vertical: 25),
                    child: CircularProgressIndicator()
                ),
              );
            },
          ),
        )
    );
  }
}
