import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:furman_now/src/layouts/app_page.dart';
import 'package:furman_now/src/services/buildings/buildings_service.dart';
import 'package:furman_now/src/store/index.dart';
import 'package:furman_now/src/widgets/info/info_card.dart';
import 'package:provider/provider.dart';

class HoursScreen extends StatelessWidget {
  const HoursScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppPageLayout(
      title: "Hours",
      icon: FlutterRemix.arrow_left_line,
      backgroundColor: Colors.blue.shade50,
      iconTapAction: () => context.router.pop(),
      content: Padding(
        padding: const EdgeInsets.all(20),
        child: Consumer<AppState>(
          builder: (context, state, _) {
            return FutureBuilder<Iterable<Building>>(
              future: state.buildings,
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  var items = snapshot.data!.where(
                    (building) => building.hoursList.isNotEmpty
                  );
                  return Column(
                    children: items.map((item) {
                      return Padding(
                        padding: const EdgeInsets.only(bottom: 15),
                        child: InfoCard(
                          title: item.name,
                          icon: FlutterRemix.building_line,
                          items: item.hoursList.map((hours) =>
                            InfoCardItem(
                              name: ""
                                "${hours.daysOfWeek} from "
                                "${hours.startTime.format(context)} - "
                                "${hours.endTime.format(context)}",
                              icon: FlutterRemix.time_line,
                            ),
                          ).toList(),
                        ),
                      );
                    }).toList(),
                  );
                }
                else if (snapshot.hasError) {
                  return Text(
                    '${snapshot.error}',
                    style: const TextStyle(color: Colors.red),
                  );
                }
                // By default, show a loading spinner.
                return const Center(
                  child: Padding(
                      padding: EdgeInsets.symmetric(vertical: 25),
                      child: CircularProgressIndicator()
                  ),
                );
              },
            );
          }
        ),
      ),
    );
  }
}