import 'package:flutter/material.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:flutter_map_location_marker/flutter_map_location_marker.dart';
import 'package:flutter_map_marker_cluster/flutter_map_marker_cluster.dart';
import 'package:furman_now/src/screens/map/state.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:latlong2/latlong.dart';
import 'package:provider/provider.dart';

class MapWidget extends StatelessWidget {
  const MapWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer<MapPageState>(
      builder: (context, state, _) => Scaffold(
        body: Stack(
          children: [
            FlutterMap(
              mapController: state.mapController,
              options: MapOptions(
                center: LatLng(34.925926, -82.439397),
                maxBounds: LatLngBounds(
                  LatLng(34.991937, -82.536251),
                  LatLng(34.813016, -82.328766),
                ),
                enableMultiFingerGestureRace: true,
                rotationWinGestures: MultiFingerGesture.all,
                pinchZoomThreshold: 0.2,
                rotationThreshold: 8,
                zoom: 15,
                minZoom: 12,
                maxZoom: 18,
                plugins: [
                  LocationMarkerPlugin(
                    centerCurrentLocationStream:
                      state.centerCurrentLocationStreamController.stream,
                    centerOnLocationUpdate: state.centerOnLocationUpdate,
                  ),
                  MarkerClusterPlugin(),
                ],
                onPositionChanged: (MapPosition position, bool hasGesture) {
                  if (hasGesture) {
                    state.centerOnLocationUpdate = CenterOnLocationUpdate.never;
                  }
                },
              ),
              layers: [
                TileLayerOptions(
                  urlTemplate:
                  "https://tile.openstreetmap.org/{z}/{x}/{y}.png",
                  userAgentPackageName: 'edu.furman.now',
                ),
                LocationMarkerLayerOptions(),
                MarkerClusterLayerOptions(
                  maxClusterRadius: 60,
                  size: const Size(40, 40),
                  fitBoundsOptions: const FitBoundsOptions(
                    padding: EdgeInsets.all(50),
                  ),
                  markers: state.markers,
                  polygonOptions: const PolygonOptions(
                      borderColor: Colors.blueAccent,
                      color: Colors.black12,
                      borderStrokeWidth: 3,
                  ),
                  builder: (context, markers) {
                    return FloatingActionButton(
                      onPressed: null,
                      child: Text(markers.length.toString()),
                    );
                  },
                ),
              ],
              nonRotatedChildren: [
                AttributionWidget(
                  attributionBuilder: (BuildContext context) {
                    return ColoredBox(
                      color: const Color(0xCCFFFFFF),
                      child: Padding(
                        padding: const EdgeInsets.all(3),
                        child: Text(
                          "©️ OpenStreetMap contributors",
                          style: furmanTextStyle(const TextStyle(
                            fontSize: 10,
                          )),
                        ),
                      ),
                    );
                  },
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}