class DaysOfWeek {
  final Weekday startDay;
  final Weekday endDay;
  final Map<Weekday, bool> days;

  DaysOfWeek({
    required this.startDay,
    required this.endDay,
    required this.days,
  });

  static Weekday _getDayFromShortName(String shortName) {
    switch(shortName.toLowerCase()) {
      case "mon":
        return Weekday.monday;
      case "tue":
        return Weekday.tuesday;
      case "wed":
        return Weekday.wednesday;
      case "thu":
        return Weekday.thursday;
      case "fri":
        return Weekday.friday;
      case "sat":
        return Weekday.saturday;
      case "sun":
        return Weekday.sunday;
      default:
        throw "Invalid date short name.";
    }
  }

  factory DaysOfWeek.parse(String s) {
    final Map<Weekday, bool> days = { for (var e in Weekday.values) e : false };

    // single day
    if (!s.contains("-")) {
      var day = _getDayFromShortName(s);
      days.update(day, (val) => true);
      return DaysOfWeek(startDay: day, endDay: day, days: days);
    }

    // date range
    var dayNames = s.split("-");
    final startDay = _getDayFromShortName(dayNames[0]);
    final endDay = _getDayFromShortName(dayNames[1]);
    int i = startDay.index;

    // loop through to add all dates in date range to list
    while(i != endDay.index) {
      days.update(Weekday.values[i], (val) => true);

      if (i < Weekday.values.length - 1) {
        i++;
      } else {
        i = 0;
      }
    }
    days.update(endDay, (val) => true);

    return DaysOfWeek(
      startDay: startDay,
      endDay: endDay,
      days: days,
    );
  }
}

enum Weekday {
  monday,
  tuesday,
  wednesday,
  thursday,
  friday,
  saturday,
  sunday,
}
