import 'dart:convert';

import 'package:external_app_launcher/external_app_launcher.dart';
import 'package:flutter/material.dart';
import 'package:flutter_remix/flutter_remix.dart';
import 'package:http/http.dart' as http;
import 'package:url_launcher/url_launcher.dart';

class ContactsService {
  static Future<Iterable<ContactInfo>> fetchContactInfo() async {
    final response = await http
      .get(Uri.parse("https://cs.furman.edu/~csdaemon/FUNow/contactsGet.php"));

    if (response.statusCode == 200) {
      // If the server did return a 200 OK response,
      // then parse the JSON.
      final healthSafetyJson = jsonDecode(response.body);
      return (healthSafetyJson["results"] as List<dynamic>).map((json) =>
        ContactInfo.fromJson(json)
      );
    } else {
      // If the server did not return a 200 OK response,
      // then throw an exception.
      throw Exception('Failed to load contact info.');
    }
  }
}

class ContactInfo {
  int id;
  int buildingId;
  String name;
  String? room;
  String number;

  ContactInfo({
    required this.id,
    required this.buildingId,
    required this.name,
    this.room,
    required this.number,
  });

  String get phone {
    return number.replaceAllMapped(
      RegExp(r'(\d{3})(\d{3})(\d+)'),
      (Match m) => "(${m[1]}) ${m[2]}-${m[3]}"
    );
  }

  void launch() async {
    var url = Uri(scheme: "tel", path: number);
    if (await canLaunchUrl(url)) {
      await launchUrl(
        url,
        mode: LaunchMode.externalApplication,
      );
    } else {
      throw "Could not launch $url";
    }
  }
  
  factory ContactInfo.fromJson(Map<String, dynamic> json) {
    return ContactInfo(
      id: int.parse(json["id"]),
      buildingId: int.parse(json["buildingID"]),
      name: json["name"],
      room: (json["room"] as String).isNotEmpty ? json["room"] : null,
      number: json["number"],
    );
  }
}

