import 'package:flutter/material.dart';
import 'package:furman_now/src/utils/conditional_parent_widget.dart';
import 'package:furman_now/src/widgets/text_with_icon.dart';

class InfoCardItem {
  final String name;
  final IconData icon;

  InfoCardItem({
    required this.name,
    required this.icon,
  });
}

class InfoCard extends StatelessWidget {
  final String title;
  final IconData icon;
  final List<InfoCardItem> items;
  final void Function()? onClick;

  const InfoCard({
    required this.title,
    required this.icon,
    required this.items,
    this.onClick,
    Key? key
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ConditionalParentWidget(
      condition: onClick != null,
      conditionalBuilder: (child) => GestureDetector(
        onTap: onClick,
        child: child,
      ),
      child: Container(
        decoration: BoxDecoration(
          color: Colors.grey.shade100,
          borderRadius: BorderRadius.circular(10),
        ),
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.only(left: 15, right: 5),
              child: Icon(
                icon,
                size: 40,
                color: Colors.grey.shade800,
              ),
            ),
            Flexible(
              child: Container(
                padding: const EdgeInsets.symmetric(horizontal: 15, vertical: 12),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(title, style: Theme.of(context).textTheme.titleSmall),
                    const SizedBox(height: 6),
                    ...(items.map((item) =>
                      TextWithIcon(
                        icon: item.icon,
                        text: item.name,
                        size: TextWithIconSize.small,
                      )
                    ).toList()),
                  ]
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
